function y = OpticalFilterBankInverted_Trapezoid(Optical_composite,FirstFilterCenter,ActiveFilters,Zero_dB_BW,CutoffMagnitude,CutoffBandwidth,FilterSpacing)  
%
% Usage: y = OpticalFilterBankInverted_Trapezoid(Optical_composite,FirstFilterCenter,ActiveFilters,Zero_dB_BW,CutoffMagnitude,CutoffBandwidth,FilterSpacing)  
%
% Purpose = This module represents a bank of optical filters, each with an inverted trapezoidal shaped logarithmic amplitude
%            transfer function (phase = 0).
%
% Input Signal(Optical_composite) = Optical Signal 
% Output Signal(y) = Optical Signal 
%
% ==== Physical Parameters ===== 
%   FirstFilterCenter = CenterFrequency of the first filter, Deviation in [Hz] from the 'Ref_Frequency'
%                     = -0.5*ChannelSpacing*(ChannelNumber-1) (default)
%   ActiveFilters = IntergerArray to define which filters are active
%                 = ones(1,ChannelNumber)    (default)
%   Zero_dB_BW = Zero dB bandwidth of the filters [Hz]
%              = BitRate (default)
%   CutoffMagnitude = Attenuation at the cutoff bandwidth of the filters [dB]
%                   = 10 (default)  
%   CutoffBandwidth = Cutoff bandwidth of the filter [Hz]
%                   = 10*BitRate (default)
%   FilterSpacing = Frequency spacing between neighboring filters in the bank.
%                 = ChannelSpacing (default) 
%
%   (global variables) f_sym DataLength BitRate ChannelSpacing ChannelNumber
%
%   Note1) Insertion Loss is NOT included. (IL can be modeled separately using function 'Attenuator'.)
%   Note2) FilterSpacing > CutoffBandwidth > Zero_dB_BW
%   Note3) For example, ActiveFilters = [1 0 1 1]
%   Note4) When ActiveFilters =1, signal will be notched out.
%   Note5) This module can be used as a WDM_Mux with INVERTED trapezoidal shape.
%          Insertion Loss should be considered at the output of this module to
%          model the Insertion Loss of a WDM Mux.
%   Note6) CutoffMagnitude defines not only slope of a filter, but also a
%          floor, i.e., the maximum suppresion of the distorting signals.
%          OpticalFilter_Trapezoid doesn't have a floor. 
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%====================================================================================
global f_sym DataLength BitRate ChannelSpacing ChannelNumber

if nargin <7
    FilterSpacing=ChannelSpacing;
end
if nargin <6
    CutoffBandwidth=10*BitRate;   
end    
if nargin<5,
    CutoffMagnitude = 10;%[dB]
end
if nargin<4,
   Zero_dB_BW = BitRate;
end
if nargin<3,
   ActiveFilters = ones(1,ChannelNumber);
end
if nargin<2,
   FirstFilterCenter = -0.5*ChannelSpacing*(ChannelNumber-1);
end

if Zero_dB_BW > CutoffBandwidth || CutoffBandwidth > FilterSpacing
  error('CutoffBandwidth should be larger than Zero_dB_BW: FilterSpacing should be larger than CutoffBandwidth: ');
 
else  
    %======== Define the filter transfer function ================
    % Magnitude transfer function for optical field
    
    for k = 1:length(ActiveFilters)
    
        if ActiveFilters(k) == 0
        
            Mag_f(k,:) = zeros(1,DataLength);
        
        else   
        
            Mag_f(k,:) = ones(1,DataLength);
            f_dev = f_sym - (FirstFilterCenter + (k-1)*FilterSpacing); Zero_dB_BW2 = Zero_dB_BW/2;
    
            Ri = find(f_dev > Zero_dB_BW2);
            Le = find(f_dev < -Zero_dB_BW2);
            Mag_f(k,Ri) = 10.^(-.1*CutoffMagnitude*(f_sym(Ri)-(FirstFilterCenter + (k-1)*FilterSpacing))/(CutoffBandwidth-Zero_dB_BW));
            Mag_f(k,Le) = 10.^(.1*CutoffMagnitude*(f_sym(Le)-(FirstFilterCenter + (k-1)*FilterSpacing))/(CutoffBandwidth-Zero_dB_BW));
            
        end 
        
    end
    
  Mag_f_perio = sum(Mag_f);

end

N_floor = 10^(-CutoffMagnitude/10);
indx_floor = (Mag_f_perio < N_floor);
Mag_f_perio(indx_floor) = N_floor;

Mag_invert = sqrt(1-Mag_f_perio.*Mag_f_perio);
%=====================================================================================
%=====================================================================================
    [a,b] = size(Optical_composite);

    if a == 1  ; %single channel case
       Optical_input = Optical_composite;
    else
       Optical_input = sum(Optical_composite); %Ideal Muxing
    end


%========= Filtering input signal with the defined optical filter =================
E_out_f = fft(Optical_input);
Filtered = fftshift(Mag_invert).*E_out_f;%

%====== Filtered Optical Field in time domain
y = ifft(Filtered);