function y = OpticalFilterInverted_Trapezoid(Optical_input,FilterCenter,Zero_dB_BW,CutoffMagnitude,CutoffBandwidth) 
%
% Usage: y = OpticalFilterInverted_Trapezoid(Optical_input,FilterCenter,Zero_dB_BW,CutoffMagnitude,CutoffBandwidth) 
%
% Purpose = This module represents an optical filter with an inverted trapezoidal shaped logarithmic amplitude
%            transfer function (phase = 0).
%
% Input Signal(Optical_input) = Optical Signal 
% Output Signal(y) = Optical Signal 
%
% ==== Physical Parameters ===== 
%   FilterCenter = Deviation in [Hz] from the 'Ref_Frequency'
%                = 0 (default)
%   Zero_dB_BW = Zero dB bandwidth of the filter [Hz]
%              = BitRate (default)
%   CutoffMagnitude = Attenuation at the cutoff bandwidth of the filter [dB]
%                   = 10 (default)
%   CutoffBandwidth = Cutoff bandwidth of the filter [Hz]
%                   = 10*BitRate (default)
%
%   (global variables) f_sym DataLength BitRate
%
% Note1) Insertion Loss is NOT included. (IL can be modeled separately using function 'Attenuator'.)
% Note2) FilterCenter = 0 corresponds to 'Ref_frequency'.  
%        Physical frequency = 'Ref_frequency' + 'f_sym'
% Note3) abs(FilterCenter) should be less than Fs/2, that is, less than max(f_sym).
% Note4) CutoffBandwidth > Zero_dB_BW
%
%------------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%====================================================================================
global f_sym DataLength

if nargin <5
    CutoffBandwidth=10*BitRate;   
end    
if nargin<4,
    CutoffMagnitude = 10;%[dB]
end
if nargin<3,
   Zero_dB_BW = BitRate;
end
if nargin<2,
   FilterCenter = 0;
end

if Zero_dB_BW > CutoffBandwidth 
  error('CutoffBandwidth should be larger than Zero_dB_BW: ');
 
else  
%======== Define the filter transfer function ================
% Magnitude transfer function for optical field

Mag_f = ones(1,DataLength);
f_dev = f_sym - FilterCenter; Zero_dB_BW2 = Zero_dB_BW/2;

Ri = find(f_dev > Zero_dB_BW2);
Le = find(f_dev < -Zero_dB_BW2);
Mag_f(Ri) = 10.^(-.1*CutoffMagnitude*(f_sym(Ri)-FilterCenter)/(CutoffBandwidth-Zero_dB_BW));
Mag_f(Le) = 10.^(.1*CutoffMagnitude*(f_sym(Le)-FilterCenter)/(CutoffBandwidth-Zero_dB_BW));

Mag_f_inverted = sqrt(1-Mag_f.*Mag_f);

end
%=====================================================================================

%========= Filtering input signal with the defined optical filter =================
E_out_f = fft(Optical_input);
Filtered = fftshift(Mag_f_inverted).*E_out_f;%'ifftshift' inverses 'fftshift'

%====== Filtered Optical Field in time domain
y = ifft(Filtered);
