function [BER,i_th,Q] = qnber_noISI(InputElectrical,info_bit,SampleTime,Threshold)
%
% Usage: [BER,i_th,Q] = qnber_noISI(InputElectrical,info_bit,SampleTime,Threshold)
%
% Purpose = This module is to calculate BER (i_th & Q) based on Gaussian assumption. (without considering ISI effects)
%         = This module can be used to find optimum values with 'QnBER_noISI_Optimum'
%
% Input1 (InputElectrical) = Single channel signal (photo-detected electrical signal), Size = [1 x DataLength]
% Input2 (info_bit) = Bit sequence sent at the transmitter
%
% Output1 (BER) = Estimated BER at the SampleTime
% Output2 (i_th) = Physical threshold value, i_th = ms0 + Threshold*(ms1-ms0) (Threshold = Relative value);  
% Output3 (Q) = Estimated Q-value at the SampleTime  
%
%==== Simulation Parameters ===============
%  SampleTime = 0.5 (default),  range = [0,1[, The normalized sampling instant relative to the bit frame.
%  Threshlold = Relative threshold value, Default = 0.5 
%
%  Note1) Q-value is defined by the relationship, BER = (1/2)*erfc(Q/sqrt(2)) ~ exp(-Q^2/2)/(Q*sqrt(2*pi).

%----------------------------------------------------------
% $ Revision: 1.0 $ Date: 2008/04/28 by Jong-Hyung Lee  
%   Revision 1.1 $ Date: 2008/10/24 by Jong-Hyung Lee
%          (New min BER = 1e-200   Old min BER = 1e-100)
%----------------------------------------------------------
%
% Reference 1. G.P. Agrawal, 'Fiber-optic Communication Systems', 2nd edition, Chapter 4
%
%======================================================================================================================
global samplesperbit Bits 

if nargin <4, Threshold = 0.5; end
if nargin <3, SampleTime = 0.5; end

marks = mean(info_bit)*Bits; spaces = Bits - marks; % Number of Marks and Spaces in Bits

%--------------------------------------------------------------------------
% 1. Generate the synchronized input pulse train
%--------------------------------------------------------------------------

[Syn_out ref_pulse] = Synchronizer(InputElectrical,info_bit);

%--------------------------------------------------------------------------
% 2. Calculate mean & std of Marks & Spaces respectively at the Sampling time 
%--------------------------------------------------------------------------

Rel_samplesperbit = round(SampleTime*samplesperbit); 
marks_v = Syn_out(ref_pulse==1);
marks_c = marks_v(Rel_samplesperbit+samplesperbit*(0:(marks-1))); % Mark values at the SampleTime of the pulse train
spaces_v = Syn_out(ref_pulse==0);
% Considering PreSpaces & PostSpaces, Remove 3 bits at each ends. 
spaces_c = spaces_v(Rel_samplesperbit+samplesperbit*(4:(spaces-4))); % Space values at the SampleTime of the pulse train
 
ms1 = mean(marks_c); std1 = std(marks_c);
ms0 = mean(spaces_c); std0 = std(spaces_c);

%--------------------------------------------------------------------------
% 3. Calculation of i_th, BER & Q   
%-------------------------------------------------------------------------- 
   
   i_th = ms0 + Threshold*(ms1-ms0);  %  'Threshold' is the given relative value. 
   Ber1 = .5*erfc(abs(ms1 - i_th)/sqrt(2)/std1);
   Ber0 = .5*erfc(abs(ms0 - i_th)/sqrt(2)/std0);
     
   BER = (marks*Ber1+(spaces-6)*Ber0)/(Bits-6);  % From Step #2, 6 Spaces has been removed.
      
                if BER < 1e-200
                     BER = 1e-200;  % BER floor
                end   
                                    
if nargout==3; % Q calculation
    
   log_ber = log(BER); % Note that it is not 'log10', but 'log' (natural logarithm)
   save ber_sim log_ber; % To be used in 'Q_value' function to calculate corresponding Q value.
   
   if log10(BER) > -9
      Q_ini = 6;           % initial assumption of Q value
   elseif log10(BER) > -50
      Q_ini = 15;
   else
      Q_ini = 20;
   end
   
   options = optimset('Display','off'); % Suppress displaying calculation process by 'fzero'
   Q = fzero('Q_value',Q_ini,options);  % 
   delete('ber_sim.mat');

end

